@@ -3,6 +3,8 @@
   Copyright (C) 2003  Razvan Cojocaru <razvanco@gmx.net>
    XML-RPC/Context ID code contributed by Eamon Millman / PCI Geomatics
   <millman@pcigeomatics.com>
+  Tree control icons code (and the icons) contributed by Fritz Elfert
+  <felfert@users.sourceforge.net>.
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -81,6 +83,8 @@ const wxChar *about_txt = wxT(
 	"Based on Jed Wing's CHMLIB (http://66.93.236.84/~jedwin/projects/).\n"
 	"XMLRPC code for context sensitive help contributed by\n"
 	"Eamon Millman <millman@pcigeomatics.com>.\n"
+	"<SPAN> tag support and contents tree icons contributed by\n"
+	"Fritz Elfert <felfert@users.sourceforge.net>.\n"
 	"Written with wxWidgets (http://www.wxwidgets.org).\n\n"
 	"This program is (proudly) under the GPL.");
 
@@ -101,14 +105,12 @@ CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir,
 	  _fixedFont(fixedFont), _fontSize(fontSize), _bookmarkSel(true),
 	  _bookmarksDeleted(false), _sashPos(sashPosition)
 {
-#ifdef _ENABLE_COPY_AND_FIND
-#	ifdef wxUSE_ACCEL
+#	if wxUSE_ACCEL
 	wxAcceleratorEntry entries[1];
 	entries[0].Set(wxACCEL_CTRL, (int) 'F', ID_FindInPage);
 	wxAcceleratorTable accel(1, entries);
 	SetAcceleratorTable(accel);
 #	endif
-#endif
 
 	int sizes[7];
 	for(int i = -3; i <= 3; ++i)
@@ -250,7 +252,7 @@ void CHMFrame::OnHome(wxCommandEvent& WXUNUSED(event))
 		return;
 
 	_html->LoadPage(wxString(wxT("file:")) + chmf->ArchiveName()
-		+ wxT("#chm:") + chmf->HomePage());
+		+ wxT("#xchm:") + chmf->HomePage());
 }
 
 
@@ -317,12 +319,10 @@ void CHMFrame::OnHistFile(wxCommandEvent& event)
 }
 
 
-#ifdef _ENABLE_COPY_AND_FIND
 void CHMFrame::OnFind(wxCommandEvent& event)
 {
 	_html->OnFind(event);
 }
-#endif
 
 
 void CHMFrame::OnAddBookmark(wxCommandEvent& WXUNUSED(event))
@@ -390,7 +390,7 @@ void CHMFrame::OnBookmarkSel(wxCommandEvent& WXUNUSED(event))
 		return;
 
 	_html->LoadPage(wxString(wxT("file:")) + chmf->ArchiveName() +
-			wxT("#chm:/") + *url);
+			wxT("#xchm:/") + *url);
 }
 
 
@@ -411,7 +411,7 @@ void CHMFrame::OnSelectionChanged(wxTreeEvent& event)
 	if(!_html->IsCaller()) {
 		_html->SetSync(false);
 		_html->LoadPage(wxString(wxT("file:")) + chmf->ArchiveName() +
-				wxT("#chm:/") + data->_url);
+				wxT("#xchm:/") + data->_url);
 		_html->SetSync(true);
 	}
 }
@@ -419,27 +419,7 @@ void CHMFrame::OnSelectionChanged(wxTreeEvent& event)
 
 void CHMFrame::OnCloseWindow(wxCloseEvent& WXUNUSED(event))
 {
-	int xorig, yorig, width, height;
-	int sashPos = _sw->IsSplit() ? _sw->GetSashPosition() : _sashPos;
-
-	GetPosition(&xorig, &yorig);
-	GetSize(&width, &height);
-
-	wxConfig config(wxT("xchm"));
-	
-	config.Write(wxT("/Position/xOrig"), xorig);
-	config.Write(wxT("/Position/yOrig"), yorig);
-	config.Write(wxT("/Position/width"), width);
-	config.Write(wxT("/Position/height"), height);
-	config.Write(wxT("/Paths/lastOpenedDir"), _openPath);
-	config.Write(wxT("/Fonts/normalFontFace"), _normalFont);
-	config.Write(wxT("/Fonts/fixedFontFace"), _fixedFont);
-	config.Write(wxT("/Fonts/size"), _fontSize);
-	config.Write(wxT("/Sash/leftMargin"), sashPos);
-
-	config.SetPath(wxT("/Recent"));
-	_fh.Save(config);
-
+	SaveExitInfo();
 	SaveBookmarks();
 	Destroy();
 }
@@ -450,8 +430,9 @@ bool CHMFrame::LoadCHM(const wxString& archive)
 	wxBusyCursor bc;
 	bool rtn;
 	SaveBookmarks();
+	_nb->SetSelection(0);
 	rtn = _html->LoadPage(wxString(wxT("file:")) + archive +
-		      wxT("#chm:/"));
+		      wxT("#xchm:/"));
 
 	UpdateCHMInfo();
 	LoadBookmarks();
@@ -473,7 +454,7 @@ bool CHMFrame::LoadContextID( const int contextID )
 		return FALSE;
 
 	return _html->LoadPage(wxString(wxT("file:")) + chmf->ArchiveName()
-		+ wxT("#chm:") + chmf->GetPageByCID( contextID ) );
+		+ wxT("#xchm:") + chmf->GetPageByCID( contextID ) );
 }
 
 
@@ -507,9 +488,6 @@ void CHMFrame::UpdateCHMInfo()
 	chmf->GetTopicsTree(_tcl);
 	chmf->GetIndex(_cip->GetResultsList());
  
-	// call the dirty method
-	_cip->GetResultsList()->ListDirty();
-
 	if(!title.IsEmpty()) {
 		wxString titleBarText = 
 			wxString(wxT("xCHM v. " VERSION ": ")) + title;
@@ -530,7 +508,8 @@ void CHMFrame::UpdateCHMInfo()
 		fontFace.BeforeLast(wxT(',')).AfterLast(wxT(',')).ToLong(&fs);
 
 		wxFont font((int)fs, wxDEFAULT, wxNORMAL, wxNORMAL, 
-			    FALSE, wxEmptyString, chmf->DesiredEncoding());
+			    FALSE, fontFace.BeforeFirst(wxT(',')), 
+			    chmf->DesiredEncoding());
 
 		if(font.Ok()) {
 
@@ -618,11 +597,7 @@ wxMenuBar* CHMFrame::CreateMenu()
 	config.SetPath(wxT("/Recent"));
 	_fh.Load(config);
 
-#ifndef _ENABLE_COPY_AND_FIND	
-	if(_fh.GetNoHistoryFiles() == 0)
-#else
 	if(_fh.GetCount() == 0)
-#endif
 		_menuFile->Enable(ID_Recent, FALSE);
 
 	_menuFile->AppendSeparator();
@@ -647,6 +622,15 @@ wxMenuBar* CHMFrame::CreateMenu()
 }
 
 
+namespace {
+
+#include <hbook_open.xpm>
+#include <hbook_closed.xpm>
+#include <hpage.xpm>
+
+} // namespace
+
+
 wxPanel* CHMFrame::CreateContentsPanel()
 {
 	wxPanel *temp = new wxPanel(_nb);
@@ -658,12 +642,19 @@ wxPanel* CHMFrame::CreateContentsPanel()
 	temp->SetAutoLayout(TRUE);
         temp->SetSizer(sizer);
 
+	wxImageList *tclBL = new wxImageList(16, 16);
+	tclBL->Add(wxIcon(hbook_closed_xpm));
+	tclBL->Add(wxIcon(hbook_closed_xpm));
+	tclBL->Add(wxIcon(hbook_open_xpm));
+	tclBL->Add(wxIcon(hbook_open_xpm));
+	wxImageList *tclIL = new wxImageList(16, 16);
+	tclIL->Add(wxIcon(hpage_xpm));
 	_tcl = new wxTreeCtrl(temp, ID_TreeCtrl, wxDefaultPosition, 
-			      wxDefaultSize, wxTR_HAS_BUTTONS |
-			      wxSUNKEN_BORDER | wxTR_HIDE_ROOT |
-			      wxTR_SINGLE | wxTR_LINES_AT_ROOT |
-			      wxTR_HAS_VARIABLE_ROW_HEIGHT | 
-			      wxTR_TWIST_BUTTONS);
+			      wxDefaultSize, wxTR_HAS_BUTTONS
+			      | wxSUNKEN_BORDER | wxTR_HIDE_ROOT
+			      | wxTR_LINES_AT_ROOT);
+	_tcl->AssignButtonsImageList(tclBL);
+	_tcl->AssignImageList(tclIL);
 
 	_cb = new wxComboBox(temp, ID_Bookmarks, wxT(""), wxDefaultPosition,
 			     wxDefaultSize, 0, NULL, wxCB_DROPDOWN 
@@ -770,6 +761,31 @@ void CHMFrame::SaveBookmarks()
 }
 
 
+void CHMFrame::SaveExitInfo()
+{
+	int xorig, yorig, width, height;
+	int sashPos = _sw->IsSplit() ? _sw->GetSashPosition() : _sashPos;
+
+	GetPosition(&xorig, &yorig);
+	GetSize(&width, &height);
+
+	wxConfig config(wxT("xchm"));
+	
+	config.Write(wxT("/Position/xOrig"), xorig);
+	config.Write(wxT("/Position/yOrig"), yorig);
+	config.Write(wxT("/Position/width"), width);
+	config.Write(wxT("/Position/height"), height);
+	config.Write(wxT("/Paths/lastOpenedDir"), _openPath);
+	config.Write(wxT("/Fonts/normalFontFace"), _normalFont);
+	config.Write(wxT("/Fonts/fixedFontFace"), _fixedFont);
+	config.Write(wxT("/Fonts/size"), _fontSize);
+	config.Write(wxT("/Sash/leftMargin"), sashPos);
+
+	config.SetPath(wxT("/Recent"));
+	_fh.Save(config);
+}
+
+
 namespace {
 
 #include <fileopen.xpm>
@@ -824,9 +840,7 @@ BEGIN_EVENT_TABLE(CHMFrame, wxFrame)
 	EVT_MENU(ID_Contents, CHMFrame::OnShowContents)
 	EVT_MENU(ID_Print, CHMFrame::OnPrint)
 	EVT_MENU_RANGE(wxID_FILE1, wxID_FILE9, CHMFrame::OnHistFile)
-#ifdef _ENABLE_COPY_AND_FIND
 	EVT_MENU(ID_FindInPage, CHMFrame::OnFind)
-#endif
 	EVT_BUTTON(ID_Add, CHMFrame::OnAddBookmark)
 	EVT_BUTTON(ID_Remove, CHMFrame::OnRemoveBookmark)
 	EVT_TREE_SEL_CHANGED(ID_TreeCtrl, CHMFrame::OnSelectionChanged)
