@@ -132,7 +132,6 @@ void CHMSearchPanel::OnSearch(wxCommandEvent& WXUNUSED(event))
 
 	if(_titles->IsChecked() && h1.empty()) {
 		PopulateList(_tcl->GetRootItem(), sr, !_partial->IsChecked());
-		_results->ListDirty();
 		_results->UpdateUI();
 		return;
 	}
@@ -140,12 +139,12 @@ void CHMSearchPanel::OnSearch(wxCommandEvent& WXUNUSED(event))
 	if(!h1.empty())
 		for(i = h1.begin(); i != h1.end(); ++i) {
 			wxString full_url = wxString(wxT("file:")) + 
-				chmf->ArchiveName() + wxT("#chm:/") + i->first;
+				chmf->ArchiveName() + wxT("#xchm:/") + 
+				i->first;
 
 			_results->AddPairItem(i->second, full_url);
 		}
     
-    _results->ListDirty();
 	_results->UpdateUI();
 }
 
@@ -164,19 +163,14 @@ void CHMSearchPanel::PopulateList(wxTreeItemId root, wxString& text,
 	if(data && (!data->_url.IsEmpty())) {
 
 		wxString url = wxString(wxT("file:")) + 
-			chmf->ArchiveName() + wxT("#chm:/") + data->_url;
+			chmf->ArchiveName() + wxT("#xchm:/") + data->_url;
 		wxString title = _tcl->GetItemText(root);
 
 		if(TitleSearch(title, text, false, wholeWords))
 			_results->AddPairItem(title, url);
 	}	
 
-#ifndef _ENABLE_COPY_AND_FIND
-	long cookie;
-#else
 	wxTreeItemIdValue cookie;
-#endif
-	
 	wxTreeItemId child = _tcl->GetFirstChild(root, cookie);
 
 	for(size_t i = 0; i < _tcl->GetChildrenCount(root, FALSE); ++i) {
@@ -256,11 +250,7 @@ bool CHMSearchPanel::TitleSearch(const wxString& title, wxString& text,
 	return found;
 }
 
-#ifdef _ENABLE_COPY_AND_FIND 
 void CHMSearchPanel::OnSearchSel(wxListEvent& WXUNUSED(event))
-#else
-void CHMSearchPanel::OnSearchSel(wxCommandEvent& WXUNUSED(event))
-#endif
 {
 	_results->LoadSelected();
 }
