@@ -1,6 +1,8 @@
 /*
 
   Copyright (C) 2003  Razvan Cojocaru <razvanco@gmx.net>
+  Tree control icons code (and the icons) contributed by Fritz Elfert
+  <felfert@users.sourceforge.net>.
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,12 +26,16 @@
 #include <wx/wx.h>
 #include <wx/fontmap.h>
 #include <string.h>
+#include <wx/utils.h>
 
 
-ContentTagHandler::ContentTagHandler(wxFontEncoding enc, bool useEnc,
-				     wxTreeCtrl* tree, CHMListCtrl *list)
-	: _level(0), _treeCtrl(tree), _listCtrl(list), _enc(enc), 
-	  _useEnc(useEnc)
+#define TIME_TO_YIELD	1024
+#define BUF_SIZE	1024
+
+
+ContentTagHandler::ContentTagHandler(wxFontEncoding enc, wxTreeCtrl* tree, 
+				     CHMListCtrl *list)
+	: _level(0), _treeCtrl(tree), _listCtrl(list), _enc(enc), _counter(0)
 {
 	if(!_treeCtrl && !_listCtrl)
 		return;
@@ -46,6 +52,13 @@ bool ContentTagHandler::HandleTag(const wxHtmlTag& tag)
 	if(!_treeCtrl && !_listCtrl)
 		return FALSE;
 
+	++_counter;
+
+	if((_counter % TIME_TO_YIELD) == 0) {
+		wxSafeYield();	
+		_counter = 0;
+	}
+
 	if (tag.GetName() == wxT("UL"))
 	{
 		if(_treeCtrl && _level >= TREE_BUF_SIZE)
@@ -97,10 +110,19 @@ bool ContentTagHandler::HandleTag(const wxHtmlTag& tag)
 				_parents[_level] = 
 					_treeCtrl->AppendItem(
 						_parents[parentIndex],
-						_title, -1, -1,
+						_title, 0, 0,
 						new URLTreeItem(_url));
 				if(!_level)
 					_parents[0] = _treeCtrl->GetRootItem();
+				else {
+					_treeCtrl->SetItemImage(
+						_parents[parentIndex], 
+						-1, wxTreeItemIcon_Normal);
+
+					_treeCtrl->SetItemImage(
+						_parents[parentIndex], 
+						-1, wxTreeItemIcon_Selected);
+				}
 			}
 
 			return TRUE;
@@ -112,25 +134,27 @@ bool ContentTagHandler::HandleTag(const wxHtmlTag& tag)
 		if(!tag.GetParam(wxT("NAME")).CmpNoCase(wxT("Name"))) {
 
 			if(_title.IsEmpty()) {
-				if(_useEnc) {
-					wxCSConv cv(wxFontMapper::Get()->
-						    GetEncodingName(_enc));
+#if wxUSE_UNICODE
+				if(_enc != wxFONTENCODING_SYSTEM) {
+					wxCSConv cv(_enc);
 
-					const wxString s = 
+					wxString s = 
 						tag.GetParam(wxT("VALUE"));
-					const size_t len = s.length();
-					wxCharBuffer buf(len);
-					char *p = buf.data();
-				
-					for ( size_t n = 0; n < len; n++ ) {
-						wxASSERT_MSG(s[n] < 0x100, 
-							     wxT("non ASCII"
-								 " char?") );
-						*p++ = s[n];
-					}
+					
+					s.Replace(wxT("&Dstrok;"),
+						  wxT("\320"), TRUE);
 
-					_title = wxString(buf, cv);
-				} else 
+					wchar_t buf2[BUF_SIZE];
+					size_t len =
+						(s.length() < BUF_SIZE) ?
+						s.length() : BUF_SIZE;
+
+					size_t ret = cv.MB2WC(buf2, s.mb_str(),
+							      len);
+					if(ret)
+						_title = wxString(buf2, ret);
+				} else
+#endif
 					_title = tag.GetParam(wxT("VALUE"));
 			}
 		}
